@@ -307,7 +307,7 @@ class MVNMixtureModel():
 
     def fit(self, steps=500, optim_fn=pyro.optim.Adam, lr=0.001, cov_type="diag", \
             loss_fn=pyro.infer.TraceEnum_ELBO(), convergence=False, initializ=True, \
-            min_steps=1, p=0.05, random_state=25):
+            min_steps=1, p=0.05, random_state=25, show_progr=True):
         pyro.enable_validation(True)
         pyro.clear_param_store()
 
@@ -329,7 +329,7 @@ class MVNMixtureModel():
             self.svi.loss(self.model, self._global_guide)
 
         losses_grad = self._train(steps=self._max_iter, convergence=convergence, \
-            min_steps=min_steps, p=p)
+            min_steps=min_steps, p=p, show_progr=show_progr)
 
         self._is_trained = True
         self.losses_grad_train = losses_grad  # store the losses and the gradients for weights/lambd
@@ -351,7 +351,7 @@ class MVNMixtureModel():
         return self.svi.loss(self.model, self._global_guide)
 
 
-    def _train(self, steps, convergence, min_steps=1, p=0.01):
+    def _train(self, steps, convergence, min_steps=1, p=0.01, show_progr=True):
         '''
         Function to perform the training of the model. \\
         `steps` is the maximum number of steps to be performed. \\
@@ -365,21 +365,19 @@ class MVNMixtureModel():
             if name in ["weights_param", "mean_param", "sigma_vector_param"]:
                 value.register_hook(lambda g, name=name: gradient_norms[name].append(g.norm().item()))
 
-        losses, nll = list(), list()
+        losses = list()
         mean_conv, sigma_conv = [self.init_params["mean"],self.init_params["mean"]], \
             [self.init_params["sigma_vector"],self.init_params["sigma_vector"]]  #to store the lambda at the previous and current iteration
         conv = 0
-        t = trange(steps, desc='Bar desc', leave=True)
+        if show_progr: t = trange(steps, desc='Bar desc', leave=True)
         for step in t:
             self.iter = step
             elb = self.svi.step() / self._N
             losses.append(elb)
 
             params_step = self._get_learned_parameters() 
-            nll.append(self._compute_nll(params=params_step))
 
             # gradient_norms = self._reset_params(params=params_step, p=.01, gradient_norms=gradient_norms)
-
             if convergence and step >= min_steps:
                 mean_conv[0], mean_conv[1] = mean_conv[1], params_step["mean"]
                 sigma_conv[0], sigma_conv[1] = sigma_conv[1], params_step["sigma_vector"]
@@ -388,9 +386,10 @@ class MVNMixtureModel():
                 if conv == 10:
                     break
             
-            t.set_description("ELBO %f" % elb)
-            t.refresh()
-        return {"losses":losses, "gradients":dict(gradient_norms), "nll":nll}
+            if show_progr:
+                t.set_description("ELBO %f" % elb)
+                t.refresh()
+        return {"losses":losses, "gradients":dict(gradient_norms)}
 
 
     # def _reset_params(self, params=None, p=.01, gradient_norms=None):
