@@ -1,6 +1,5 @@
-from mvnmm import MVNMixtureModel
-from run_inference import run_inference
-import pyro, torch
+from .run_inference import run_inference
+import torch
 import pyro.distributions as distr
 import pickle
 
@@ -95,8 +94,8 @@ def generate_synthetic_data(N_range, T_range, K_range, mean_loc_range, mean_scal
                             sim.generate_dataset() 
                             inf = sim.run_inference_sim()
                             
-                            with open(sim.sim_id+".df", 'wb') as sim_file:
+                            with open(sim.sim_id+".df.pkl", 'wb') as sim_file:
                                 pickle.dump(sim, sim_file)
 
-                            with open(sim.sim_id+".run", 'wb') as inf_file:
+                            with open(sim.sim_id+".run.pkl", 'wb') as inf_file:
                                 pickle.dump(inf, inf_file)
